Index: src/objects.h |
diff --git a/src/objects.h b/src/objects.h |
index 378314e2014f4b2b7599841b0b7658b2acfb5a96..057421a7c34b37bc851bff90b9d6baa53eaed17c 100644 |
--- a/src/objects.h |
+++ b/src/objects.h |
@@ -1593,11 +1593,13 @@ class JSObject: public HeapObject { |
void LookupInDescriptor(String* name, LookupResult* result); |
- // Attempts to get property with a named interceptor getter. |
- // Sets |attributes| to ABSENT if interceptor didn't return anything |
- Object* GetPropertyWithInterceptorProper(JSObject* receiver, |
- String* name, |
- PropertyAttributes* attributes); |
+ // Attempts to get property with a named interceptor getter. Returns |
+ // |true| and stores result into |result| if succesful, otherwise |
+ // returns |false| |
+ bool GetPropertyWithInterceptorProper(JSObject* receiver, |
+ String* name, |
+ PropertyAttributes* attributes, |
+ Object** result); |
DISALLOW_IMPLICIT_CONSTRUCTORS(JSObject); |
}; |
@@ -3270,6 +3272,9 @@ class JSRegExp: public JSObject { |
inline Object* DataAt(int index); |
// Set implementation data after the object has been prepared. |
inline void SetDataAt(int index, Object* value); |
+ static int code_index(bool is_ascii) { |
+ return is_ascii ? kIrregexpASCIICodeIndex : kIrregexpUC16CodeIndex; |
+ } |
static inline JSRegExp* cast(Object* obj); |